==> haskell-ieee754-0.8.0-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
key:                  ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  5bf523d886eb0e5ff893fc0d25a23119
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ieee754
hs-libraries:         HSieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ieee754-0.8.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
key:                  ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  ebcf4dc823e831f6e27c85d4558fa3da
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ieee754-0.8.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ieee754
hs-libraries:         HSieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
